<?php
/*
 *      ImportConfig-inc.php
 *			Laden einer config.inc.php in DB
 *			Es werden nur Einträge in DB gespeichert, wenn die Variable in DB definiert ist.
 *			Config.Inc-Variablen, die nicht in DB definiert sind, werden lediglich als Hinweis
 *			am Ende angezeigt.
 *			Aufruf über CLI oder Web möglich
 *			Bei Benutzung über Web erfolgt der Aufruf über SelectBackup.js
 *			Auswahl, ob alle Einträge geladen werden oder nur die, die
 *			sich von den DB-Einträgen unterscheiden
 *			
 *      Copyright (C)  2017 © Vetsoft Office Projekt <http://www.http://www.vetsoft.de/>
 *                     Dirk Walter (DW),
 *                     Klaus Munsteiner (KM), 
 *                     Markus Angeli (MA)
 *					   Eric Walter (EW)
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */

//2017-03-22 V 1.0 EW
//

  include_once "../admin/include/classes.inc.php";
  include_once "../admin/include/functions.inc.php";

  $HelpText="Usage:\n\tImportConfig-inc.php [-a] -c {config-inc-Filename} [-d {vs_db_objects.php Filename (!! NICHT die inc Datei !!}]\n";
  $HelpText=$HelpText."\t\t -a: Alles importieren, egal, ob Eintraege in DB und config-inc gleich sind\n";

  
//********************************************************************
// MAIN
//********************************************************************

  $ImportAll=FALSE;

  // Wird von der Command Line aufgerufen
  if (php_sapi_name() == "cli") {
  	$CR="\n";
    // -a -> ALLE importieren (all)
    // -c -> config.inc.php Filename mit Pfad
    // -d -> vs_db_objects_inc.php mit Pfad

    $options = getopt("ad:c:");
	if ( isset ($options['a']) ) {
		$ImportAll=TRUE;
	} 
	if ( (isset ($options['c'])) && ($options['c'] != "")) {
		if ( is_file($options['c']) ) {
			define ("configIncFile",$options['c']);
		} else {
			echo $HelpText;
			echo "\n\tFEHLER: config.inc-File:".$options['c']." exisitiert nicht".$CR;
			echo "\tABBRUCH".$CR;
			exit (1);
		}
	} else {
		echo $HelpText;
		exit (1);
	}
	if ( isset ($options['d']) ) {
		if ( is_file($options['d']) ) {
		   include_once $options['d'];
		} else {
			echo $HelpText;
			echo "\n\tFEHLER: db-include-File:-".$options['d']."- exisitiert nicht".$CR;
			echo "\tABBRUCH".$CR;
			exit (1);
		}
	} else {
		include_once "../vs_lib/vs_db_objects.php";
	}
  } else { // call from Apache/Browser
	$CR="<BR>";
  	if (isset($_POST['all'])){
		$ImportAll=TRUE;
  	}
	
  	if (isset($_POST['ci'])){
		define ("configIncFile",$_POST['ci']);
		include_once "../vs_lib/vs_db_objects.php";
  	} else {
  		echo "Config.inc File unbekannt<BR>";
	  	echo "Exiting<BR>";
  		exit ();
  	}
  }
  
  if (is_file(configIncFile)) {
  		include_once configIncFile;
  } else {
  		echo "\tConfig-Inc Datei existiert nicht ". configIncFile.$CR;
  		echo "\texiting ...$CR";
  		exit();
  }

  $undefinedCI = array ();
  $definedCI = array ();
  $undefinedDB = array ();
  $undefCIct=0;
  $undefDBct=0;
  $diffct=0;
  
  $pattern = "/^define/i"; // nur Zeilen, die mit define anfangen
  $configIncEntries = preg_grep($pattern, file(configIncFile));

  foreach ($configIncEntries as $line) {
  	$newline=explode ("\"",$line);
	$definedCI[]=$newline[1];
  }

  foreach ($definedCI as $var) {
	if (! VarExists($var) ){
		$undefinedDB[] = $var;
		$undefDBct++;
	}
  }

  // $clist = alle DB-Einträge
  $clist=GetAllConfigs();
  foreach ($clist as $config) {

  	if ( defined ($config->var_name)) {
  		// Nur Speichern wenn DB und config.inc unterschiedlich
  		if (strcmp($config->var_value, constant($config->var_name)) !== 0) {
  			$diffct++;
			$config->var_value= constant($config->var_name);
			$config->dbupdate_value();	
		} elseif ( $ImportAll == TRUE ) {
		// Alle Speichern 
			$config->var_value= constant($config->var_name);
			$config->dbupdate_value();
		}
	} else {
		$undefCIct++;
		$undefinedCI[]=$config->var_name;
	}
  }


  echo "$CR Anzahl Eintraege in config.inc:".count($configIncEntries);
  echo "$CR Anzahl Eintraege in DB:".count($clist).$CR;

  echo "$CR Anzahl unterschiedlicher Eintraege: $diffct.$CR";
  echo "$CR $CR $undefCIct Konstanten existieren NICHT in CONFIG.INC $CR";
  foreach ($undefinedCI as $undef) {
  	echo "\t$undef $CR";
  }
  if ( count ($undefinedCI) != 0 ) {
  	echo "  !!!!!! ACHTUNG: ES WERDEN HIER DIE DEFAULTWERTE DER DB UEBERNOMMEN !!!! $CR $CR";
  }

  echo "$CR $CR $undefDBct Konstanten existieren NICHT in der DATENBANK: $CR";
  foreach ($undefinedDB as $undef) {
  	echo "\t$undef $CR";
  }
  if ( count ($undefinedDB) != 0 ) {
  	echo "  !!!!!! ACHTUNG: ES MUSS HIER GGFS. IN DER DB NACHGEARBEITET WERDEN !!!! $CR $CR";
  }

  echo " === ENDE === $CR";
  exit(0);
// ============================== END MAIN ==============================
  
//********************************************************************
// VarExists
//********************************************************************
function VarExists ($var_name) {
	$rc=0;
	$db = new vs_db();
	$db->connect();
	$query="SELECT var_name FROM vs_config WHERE var_name = '$var_name'";
	$rs=$db->query ($query);
	$rc=$db->num_rows ($rs);
	$db->free_result();
	return $rc;
}

?> 
