#!/bin/bash
#      UpdateVS.sh
#			Vetsoft-Update 1.82 -> 1.90
#      
#      Copyright (C)  2017 © Vetsoft Office Projekt <http://www.http://www.vetsoft.de/>
#                     Dirk Walter (DW),
#                     Klaus Munsteiner (KM), 
#                     Markus Angeli (MA)
#					   Eric Walter (EW)
#      
#      This program is free software; you can redistribute it and/or modify
#      it under the terms of the GNU General Public License as published by
#      the Free Software Foundation; either version 2 of the License, or
#      (at your option) any later version.
#      
#      This program is distributed in the hope that it will be useful,
#      but WITHOUT ANY WARRANTY; without even the implied warranty of
#      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#      GNU General Public License for more details.
#      
#      You should have received a copy of the GNU General Public License
#      along with this program; if not, write to the Free Software
#      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
#      MA 02110-1301, USA.
#
#
# 2017-03-29 V 1.0 EW
#

######################################################################
# function LogVars
#    Alle Variablen werden in Logdatei geschrieben
#    Wird zwinged fuer "RevokeUpdate.sh" benoetigt
######################################################################
function LogVars {
	LOGFILE=VSUpdateVars.log
	echo > $LOGFILE
	for i in $VARS ; do
		echo "$i=${!i}" >>  $LOGFILE
	done
}

TEXT=( 'Web Root Verzeichnis' 'Aktuelles Vetsoft Root Verzeichnis' 'Vetsoft Update Verzeichnis' 'Apache Username' 'Apache Gruppenname' 'DB Hostname' 'DB Port' 'DB Name' 'DB Username' 'DB User Passwort' 'DB Admin User')
VARS="WWWHOME VSOLDHOME VSNEWHOME WWWUSER WWWGRP DBHOST DBPORT DBNAME DBUSER DBUSERPW DBAUSER"

VSVERSION=1.90
DBAUSER="postgres"
WWWHOME=`pwd | awk -F"/vs${VSVERSION}" '{ print $1 }'`
VSNEWHOME=$WWWHOME/vs$VSVERSION


# Location vs_db_objects_inc.php ausfindig machen
if [ -f $WWWHOME/vs/vs_lib/vs_db_objects_inc.php ] ; then
   VSOLDHOME=$WWWHOME/vs
elif [ -f $WWWHOME/vs_lib/vs_db_objects_inc.php ] ; then
   VSOLDHOME=$WWWHOME/vs
else
   VSOLDHOME=""
   echo " Kann vs_db_objects_inc.php nicht finden"
   echo " ABBRUCH"
   exit 1
fi

# Apache User ausfindig machen
WWWUSER=`ps awux | grep apache2 | egrep -v 'root|grep'| cut -f 1 -d " " | uniq | head -1`
WWWGRP=`id -ng $WWWUSER`

# DB connectstring in Array aufsplitten
CONNECTSTRING=`sed "s/^[ \t]*//" < $VSOLDHOME/vs_lib/vs_db_objects_inc.php | grep "^define" | grep "vs_constring" | cut -f 4 -d"\""`

# Einzelteile des DB connectstrings in Variablen speichern
for f in $CONNECTSTRING ; do
  VAR=`echo $f | cut -f 1 -d "="` 
  VALUE=`echo $f | cut -f 2 -d "="`
  case $VAR in
    "host")
       DBHOST=$VALUE
       ;;
    "port")
       DBPORT=$VALUE
       ;;
    "dbname")
       DBNAME=$VALUE
       ;;
    "user")
       DBUSER=$VALUE
       ;;
    "password")
       DBUSERPW=$VALUE
       ;;
  esac
done

# Alle benötigten Variablen vom Benutzer interaktiv ueberporuefen lassen
ct=0
for i in $VARS ; do
  echo -n "${TEXT[$ct]} [${!i}]: "
  read TMP
  if [ -n "$TMP" ] ; then
    eval $i=\$TMP
    unset TMP
  fi
  ct=$((ct + 1))
done

ct=0
# Es darf keine Variable leer sein
for i in $VARS ; do
  if [ -z  "${!i}" ] ; then
     echo -e  "\n\n   Variable fuer ${TEXT[$ct]} darf nicht leer sein \n   ABBRUCH\n\n"
     exit 1
  fi
  ct=$((ct + 1))
done

# Variablen in Datei abspeichern
echo -e "\n\n\n"
LogVars


# Check ob "short_open_tag=on" in php.ini fuer CLI
echo " ... Check short_open_tag = On in php.ini (CLI)"
PHPINI=`echo "<?php echo get_cfg_var('cfg_file_path'); ?>" | /usr/bin/php`
SOT=`awk '{if ($1 == "short_open_tag") print $0}' $PHPINI | cut -f 2 -d "="`
# Delete leading Whitespace
SOT=`echo $SOT | tr '[:upper:]' '[:lower:]'`
if [ "$SOT" != "on" ] ;  then
  echo " FEHLER: short_open_tag in $PHPINI muss auf \"on\" stehen"
  echo " ABBRUCH"
  exit 1
fi

echo  " DONE"


# Ueberpruefung der DB-Version
echo " ... Check Vetsoft DB Version"
DBVERSION=`./bin/GetDbVersion.php $VSOLDHOME`
if [ "$DBVERSION" != "1.82" ] ;  then
  echo " Falsche DB Version $DBVERSION"
  echo " erforderliche DB Version 1.82"
  echo " ABBRUCH"
  exit 1
fi
echo  " DONE"

DATUM=`date +%Y-%m-%d_%H:%M:%S`

# Alle Dateien gehören zu Apache User
echo " ... Setze Zuriffsrechte fuer $WWWUSER"
   chown -R ${WWWUSER}.${WWWGRP} $VSNEWHOME
echo  " DONE"

# Backup vor Update erzeugen
echo  " ... Erzeuge Backup vom Original-System im Verzeichnis ./Backup"
tar cf Backup/vetsoft-Home-${DATUM}.tar -C $VSOLDHOME .
sudo -u $DBAUSER pg_dump -Fc $DBNAME > /tmp/vetsoft-DB-${DATUM}.backup
mv /tmp/vetsoft-DB-${DATUM}.backup ./Backup
echo  " DONE"

# Passwortfeld in DB-Tabelle vs_user verlaengern wg. PW-Verschluesselung
echo " ... Aenderung Passwortlaenge in vs_user"
./bin/ExecSqlScript.sh -d $DBNAME -a $DBAUSER -s bin/UpdateUserTableStruct.sql
echo  " DONE"

# PWs in DB verschluesseln
echo " ... Konvertierung Passworte"
./bin/ConvertPwTable.php $VSOLDHOME
echo  " DONE"

# vs_config Tabelle eerzeugen und per Import mit default-Werten belegen
echo " ... Erzeugung vs_config Tabelle"
./bin/ExecSqlScript.sh -d $DBNAME -a $DBAUSER -o $DBUSER -s bin/cre_vs_config.sql
sudo -u $DBAUSER psql $DBNAME < etc/vs_config-table.dmp
echo  " DONE"

# Kundenspezifische config_inc.php in vs_config einlesen
echo " ... Importieren der config.inc in vs_config Tabelle"
IMPORTSCR=$WWWHOME/vs${VSVERSION}/admin/ImportConfig-inc.php
if [ ! -f "$IMPORTSCR" ] ; then
   echo " Importscript ($IMPORTSCR) konnte nicht gefunden werden"
   echo " ABBRUCH"
   exit 1
fi
CONFIGINC=$VSOLDHOME/vs_office_inc/config.inc.php
if [ ! -f "$CONFIGINC" ] ; then
   echo " config.inc.php ($CONFIGINC) konnte nicht gefunden werden"
   echo " ABBRUCH"
   exit 1
fi

(cd $WWWHOME/vs${VSVERSION}/admin; /usr/bin/php $IMPORTSCR -a -c $CONFIGINC -d $VSOLDHOME/vs_lib/vs_db_objects.php)
echo  " DONE"

# Logo kopieren 
echo " ... Logo kopieren"
LOGO=`grep \"logo\" $CONFIGINC | awk -F "(" '{print $2}' | awk -F"\"" '{ print $4 }'`

FIRSTCHAR=`echo $LOGO | head -c 1`

# Unterscheidung relativer / absoluter Pfadname
if [ "$FIRSTCHAR" == "." ] ; then
	OLDLOGO=$VSOLDHOME/vs_office_inc/$LOGO
	NEWLOGO=$VSNEWHOME/vs_office_inc/$LOGO
else
	OLDLOGO=$VSOLDHOME/$LOGO
	NEWLOGO=$VSNEWHOME/$LOGO
fi
cp $OLDLOGO $NEWLOGO
echo  " DONE"

# vs_db_objects_inc.php ins neue vetsoft-Verzeichnis kopieren
echo " ... Neue vs_db_objects_inc.php kopieren"
if [ -f $VSNEWHOME/vs_lib/vs_db_objects_inc.php ] ; then
   cp $VSNEWHOME/vs_lib/vs_db_objects_inc.php $VSNEWHOME/vs_lib/vs_db_objects_inc.php.$DATUM
fi
cp $VSOLDHOME/vs_lib/vs_db_objects_inc.php $VSNEWHOME/vs_lib/vs_db_objects_inc.php
echo  " DONE"

# DB-Version aktualisieren
echo " ... Neue DB-Version setzen"
./bin/ExecSqlScript.sh -d $DBNAME -a $DBAUSER -o $DBUSER -s bin/UpdateVsDbVersion.sql
echo  " DONE"

exit
