<?php
/*
 *      vs_db_objects.php
 *      
 *      Copyright (C)  2005 - 2012 © Dr. Norbert Klumpp
 *      
 *      Copyright (C)  2013 - 2015 © Vetsoft Office Projekt <http://www.http://www.vetsoft.de/>
 *                     Dirk Walter (DW),
 *                     Klaus Munsteiner (KM), 
 *                     Markus Angeli (MA)
 *      
 *      This program is free software; you can redistribute it and/or modify
 *      it under the terms of the GNU General Public License as published by
 *      the Free Software Foundation; either version 2 of the License, or
 *      (at your option) any later version.
 *      
 *      This program is distributed in the hope that it will be useful,
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of
 *      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *      GNU General Public License for more details.
 *      
 *      You should have received a copy of the GNU General Public License
 *      along with this program; if not, write to the Free Software
 *      Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 *      MA 02110-1301, USA.
 */




  //  ***************************************************
  //  *Datenbank Objecte                                *
  //  ***************************************************

  //anwendungsspezifische Daten, werden vom Konstruktor eingelesen
  //alternativ kann der Konstruktor mit anderen Daten aufgerufen werden
  //falls z.B. zwischendurch mit einer anderen Datenbankverbindung gearbeitet wird
  
  // 2014-09-11 KM: Fuer PHP 5.5.9 angepasst.


include_once "vs_db_objects_inc.php"; //definiert den Standarddatenbankzugang
  
class vs_field
{
  public $name;
  public $label;
  public $typ;
  public $len;
  public $formatstr;
  public $align;
  
  public function __construct()
  {
  	$this->name="";
  	$this->label="";
  	$this->typ="";
  	$this->len=0;
  	$this->formatstr="";
  	$this->align="left";
  }
}  
  
class vs_db
{
  //Zugang       //*****************************************************
  public $dbtyp;    //*1,2,3,4 : (Postgre,MySQL,Firebird/Interbase,SQLite)*
  public $dbname;   //*****************************************************
  public $host;
  public $port;
  public $user;
  public $pw;
  public $constring;
  //interner Gebrauch
  public $link;
  public $result;
  public $currentrow;
  public $fields;     //array mit vs_fields
  public $limitchar;  //Trennzeichen für stringfelder,z.B. function curr_row_as_string  
  public $olddata;    //Datensatz vor dem Ändern als string;
  public $numrows;
  public $sql;
  
  public function __construct($dbtyp=vs_dbtyp,$constring=vs_constring,$dbname=vs_dbname,$host=vs_host,$port=vs_port,$user=vs_user,$pw=vs_password)
  {
    $this->dbtyp = $dbtyp;
    $this->dbname= $dbname;
    $this->host = $host;
    $this->port = $port ;
    $this->user = $user;
    $this->pw = $pw;
    $this->constring = $constring;
    //intern
    $this->limitchar="#"; // # wird im normalen Text kaum vorkommen
    $this->sql="";
 }
 
  public function num_count($table,$bedingung)
  {
  	$this->query("select * from $table where $bedingung");
  	$n = $this->num_rows();
  	$this->free_result();
  	return $n;
  }
  
  public function get_fields()
  
  {
   for ($i=0;$i<$this->num_fields();$i++)
   {
    $f1 = new vs_field;
    $f1->name = $this->field_name($i);
    $f1->len = $this->field_len($i); 
    $f1->typ = $this->field_type($i);
    $f1->label = ucfirst($this->field_name($i));
    $this->fields[$i]=$f1;
   }
  }
  
  public function curr_row_as_string()
  //gibt die aktuelle Zeile als String mit dem Trennzeichen limitchar zurueck
  //verwendet v.a. als Duplikat der Daten
  { 
  	if ($this->numrows>0)
  	{
   	  $s=implode($this->limitchar,$this->currentrow);
   	  return rawurlencode($s);
  	}
  	else return "";
  }	
  
  public function connect()
  {
   switch ($this->dbtyp)
     {  case "1":
	    $this->link = pg_connect($this->constring);
	    pg_query ($this->link,"set datestyle to german");
	    return $this->link;               // Hinzugefügt 31.05.2013 MA
	    break;
        case "2":
	    $this->link =mysql_connect($this->constring);
	    mysql_select_db($this->dbname);
	    break;
	  case "3":
         $this->link=ibase_connect($this->constring);
	     break;
	  case "4":
	     //0666 -> siehe Referenz
	     $this->link= sqlite_open($this->constring,0666,$sqliteerror);
	     break;
     }	    
  }
    
  public function query($sql)
  {
   unset($this->result);	
   //error_log('vetsoftdebugtrick: auskommentieren zum Debuggen SQL-Text: ' . $sql);
   $this->sql=$sql;
   $this->sql=$sql;
   switch ($this->dbtyp)
     {  case "1":
	      $this->result = pg_query($this->link,$sql);
	    break;
        case "2":
	      $this->result = mysql_query($sql,$this->link);
	    break;
	    case "3":
          $this->result = ibase_query($this->link,$sql);
	    break;
	    case "4":
	      $this->result = sqlite_query($this->link,$sql);
	    break;
     }	 
     //$this->get_fields(); //holt Feldinformationen
  }

  public function last_error()
  {
   switch ($this->dbtyp)
     {  case "1":
	      $error = pg_last_error($this->link);
	    return $error;
	    break;
        case "2":
	   
	    break;
	    case "3":
            $error= ibase_errmsg();
         return($error);
	    break;
	    case "4":
	  
	    break;
     }	   
  }

  public function num_rows()
  {
   switch ($this->dbtyp)
     {  case "1":
	    $rows = pg_num_rows($this->result);
	    return $rows;
	    break;
          case "2":
	      $rows = mysql_num_rows($this->result);
	    return $rows;
	    break;
	  case "3":
            return $GLOBALS["ar_count_queries"][$this->result];
	    break;
	  case "4":
	  
	   break;
     }	   
  
  }
 
  
  public function num_fields()
  {
   switch ($this->dbtyp)
     {    case "1":
	    $fields = pg_num_fields($this->result);
	    return $fields;
	    break;
          case "2":
	    $fields = mysql_num_fields($this->result);
	    return $fields;
	    break;
	  case "3":
            $fields=ibase_num_fields($this->result);
            return($fields);
	    break;
	  case "4":
	    
	   break;
     }	   
  
  }
  
  public function field_name($nr)
  {
   switch ($this->dbtyp)
     { case "1":
	      $name = pg_field_name($this->result,$nr);
	      return $name;
	    break;
        case "2":
	      $name = mysql_field_name($this->result,$nr);
	      return $name;
	    break;
	    case "3":
          $col_info = ibase_field_info($this->result,$nr);
          $name=$col_info["name"];
          return($name);
	    break;
	    case "4":
	  
	    break;
     }	   
  
  }
   
  public function field_type($nr)
  {
   switch ($this->dbtyp)
     {    case "1":
	    $typ = pg_Field_type($this->result,$nr);
	    return $typ;
	    break;
          case "2":
	    $typ = mysql_field_type($this->result,$nr);
	    return $typ;
	    break;
	  case "3":
            $col_info = ibase_field_info($this->result,$nr);
            $typ=$col_info["type"];
            return($typ);
	    break;
	  case "4":
	  
	    break;
     }	   
  
  }
  
  
  public function field_len($nr)
  {
   switch ($this->dbtyp)
     {    case "1":
            //vorerst, muss selbst implementiert werden
	    $len = pg_field_size($this->result,$nr);
	    return $len;
	    break;
	   /* $typ=pg_field_type($this->result,$nr);
	      switch($typ)
	      {
	       case "timestamp": 
	         return 19;
	         break;
	       case "bool": 
	         return 1;
	         break;	 
	       case "time":
	         return 8;
	         break;
	       case "date":
	         return 10;
	         break;
	       case "bpchar":
	         return pg_field_size($this->result,$nr);
	         break;	 
	       default:
	         return 20;
	      }
	      break;
	   */
          case "2":
	    $len = mysql_field_len($this->result,$nr);
	    return $len;
	    break;
	  case "3":
            $col_info = ibase_field_info($this->result,$nr);
            $len=$col_info["length"];
            return($len);
	    break;
	  case "4":
	  
	  break;
     }	   
  
  }
  
  
  public function fetch_row()
  {
   switch ($this->dbtyp)
     {case "1":
	        $this->currentrow = pg_fetch_row($this->result);
	        $this->numrows=$this->num_rows();
	        return $this->currentrow;
	        break;
      case "2":
	        $this->currentrow =mysql_fetch_row($this->result);
	        $this->numrows=$this->num_rows();
	        return $this->currentrow;
	        break;
	  case "3":
            $this->currentrow=ibase_fetch_row($this->result);
            $this->numrows=$this->num_rows();
            return($this->currentrow);
	        break;
	  case "4":
	        $this->currentrow=sqlite_fetch_row($this->result);
	        $this->numrows=$this->num_rows();
            return($this->currentrow);
	        break;
     }	   
  
  }
  
  public function fetch_object()
  {
   switch ($this->dbtyp)
     {    case "1":
	       $o = pg_fetch_object($this->result);
	       return $o;
	    break;
          case "2":
	       $o = mysql_fetch_object($this->result);
	       return $o;
	       break;
	  case "3":
           $o=ibase_fetch_object($this->result);
           return($o);
	       break;
	  case "4":
	       $o=sqlite_fetch_object($this->result);
           return($o);
	       break;
     }	   
  } 
     
  public function fetch_array()
  {
   switch ($this->dbtyp)
     {
      case "1":
	    $a = pg_fetch_array($this->result);
	    return $a;
	    break;
      case "2":
	    $a = mysql_fetch_array($this->result);
	    return $a;
	    break;
	  case "3":
	        //muss selbst gebastelt werden, da von ibase nicht unterstuetzt,nicht getestet!!!
            $row=ibase(fetch_row($this->result));
            for ($i=0;$i<count($this->fields);$i++)
            {
             $a[$this->fields[$i]->name]=$this->row[$i];	
            }	
            return($a);
	    break;
	  case "4":
	  
	  break;
     }	   
  } 
       
  public function free_result()
  {
   if ((isset($this->result) and ($this->result!=false)))
   {	
    switch ($this->dbtyp)
     {case "1":
	    pg_free_result($this->result);
	    break;
      case "2":
	    @mysql_free_result($this->result);//@wegen sonst permanenter Warnungen
	    break;
	  case "3":
        ibase_free_result($this->result);
	    break;
	  case "4":
	    sqlite_free_result($this->result);
	    break;
     }	 
     unset($this->result);
     unset($this->fields);  
   }  
  }
  
  
  public function close()
  {
    if(isset($this->result))
    {
      $this->free_result();
    }	
    switch ($this->dbtyp)
     {case "1":
	    pg_close($this->link);
	    break;
      case "2":
	    mysql_close($this->link);
	    break;
	  case "3":
        ibase_close($this->link);
	    break;
	  case "4":
	    sqlite_close($this->link);
	    break;
     }	 
     unset($this->link);
    }
  
  //-------------Neue Funktionen----------------------------------------------------
  public function before_edit($table,$indexfield,$indexvalue)
  {
  	$this->query("Select * from $table where $indexfield=$indexvalue");
  	$row=$this->fetch_row();
  	$this->olddata=$this->curr_row_as_string();
  	$this->free_result();
  }
  
  public function check_dependent($deptable,$depfield,$indexvalue)
  {
  	$this->query("Select count(*) from $deptable where $depfield=$indexvalue");
  	$row=$this->fetch_row();
  	$this->free_result();
  	return $row[0];
  }
  
//Ende des Objectes
}
?>
